##  FAQ
### Why can I not delete the IdP?
Active IdPs cannot be deleted as this would remove access to the workspace for the users on this IdP. Check if the IdP is still active before deleting it.
If there is only a single IdP configured, it cannot be deleted as otherwise you and your users would lose all access to SAP LeanIX.
YesNo
Send
